==> owncloud-9.0.3.tgz: owncloud/lib/l10n/sv.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Kan inte skriva till \"config\" katalogen!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Detta kan vanligtvis åtgärdas genom att ge skrivrättigheter till config katalgogen",
    "See %s" : "Se %s",
    "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "Detta kan vanligtvis åtgärdas genom att %s ger webbservern skrivrättigheter till konfigurations-katalogen %s.",
    "Sample configuration detected" : "Exempel-konfiguration detekterad",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Det har detekterats att exempel-konfigurationen har kopierats. Detta kan förstöra din installation och stöds ej. Vänligen läs dokumentationen innan ändringar på config.php utförs",
    "PHP %s or higher is required." : "PHP %s eller högre krävs.",
    "PHP with a version lower than %s is required." : "PHP med version lägre än %s krävs.",
    "Following databases are supported: %s" : "Följande databastyper stödjs: %s",
    "The command line tool %s could not be found" : "Kommandoradsverktyget %s hittades inte.",
    "The library %s is not available." : "Biblioteket %s är inte tillgängligt.",
    "Library %s with a version higher than %s is required - available version %s." : "Bibliotek %s med version högre än %s krävs - tillgänglig version %s.",
    "Library %s with a version lower than %s is required - available version %s." : "Bibliotek %s med version lägre än %s krävs - tillgänglig version %s.",
    "Following platforms are supported: %s" : "Följande plattformar stödjs: %s",
    "ownCloud %s or higher is required." : "ownCloud %s eller högre krävs.",
    "Help" : "Hjälp",
    "Personal" : "Personligt",
    "Users" : "Användare",
    "Admin" : "Admin",
    "Recommended" : "Rekomenderad",
    "No app name specified" : "Inget appnamn angivet",
    "Unknown filetype" : "Okänd filtyp",
    "Invalid image" : "Ogiltig bild",
    "today" : "i dag",
    "yesterday" : "i går",
    "_%n day ago_::_%n days ago_" : ["%n dag sedan","%n dagar sedan"],
    "last month" : "förra månaden",
    "_%n month ago_::_%n months ago_" : ["%n månad sedan","%n månader sedan"],
    "last year" : "förra året",
    "_%n year ago_::_%n years ago_" : ["%n år sedan","%n år sedan"],
    "_%n hour ago_::_%n hours ago_" : ["%n timme sedan","%n timmar sedan"],
    "_%n minute ago_::_%n minutes ago_" : ["%n minut sedan","%n minuter sedan"],
    "seconds ago" : "sekunder sedan",
    "web services under your control" : "webbtjänster under din kontroll",
    "File name contains at least one invalid character" : "Filnamnet innehåller minst ett ogiltigt tecken",
    "App directory already exists" : "Appens mapp finns redan",
    "Can't create app folder. Please fix permissions. %s" : "Kan inte skapa appens mapp. Var god åtgärda rättigheterna. %s",
    "No source specified when installing app" : "Ingen källa angiven vid installation av app ",
    "No href specified when installing app from http" : "Ingen href angiven vid installation av app från http",
    "No path specified when installing app from local file" : "Ingen sökväg angiven vid installation av app från lokal fil",
    "Archives of type %s are not supported" : "Arkiv av typen %s stöds ej",
    "Failed to open archive when installing app" : "Kunde inte öppna arkivet när appen skulle installeras",
    "App does not provide an info.xml file" : "Appen har ingen info.xml fil",
    "App can't be installed because of not allowed code in the App" : "Appen kan inte installeras eftersom att den innehåller otillåten kod",
    "App can't be installed because it is not compatible with this version of ownCloud" : "Appen kan inte installeras eftersom att den inte är kompatibel med denna version av ownCloud",
    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "Appen kan inte installeras eftersom att den innehåller etiketten <shipped>true</shipped> vilket inte är tillåtet för icke inkluderade appar",
    "Application is not enabled" : "Applikationen är inte aktiverad",
    "Authentication error" : "Fel vid autentisering",
    "Token expired. Please reload page." : "Ogiltig token. Ladda om sidan.",
    "Unknown user" : "Okänd användare",
    "%s enter the database username." : "%s ange databasanvändare.",
    "%s enter the database name." : "%s ange databasnamn",
    "%s you may not use dots in the database name" : "%s du får inte använda punkter i databasnamnet",
    "Oracle connection could not be established" : "Oracle-anslutning kunde inte etableras",
    "Oracle username and/or password not valid" : "Oracle-användarnamnet och/eller lösenordet är felaktigt",
    "DB Error: \"%s\"" : "DB fel: \"%s\"",
    "Offending command was: \"%s\"" : "Det felaktiga kommandot var: \"%s\"",
    "You need to enter either an existing account or the administrator." : "Du måste antingen ange ett befintligt konto eller administratör.",
    "Offending command was: \"%s\", name: %s, password: %s" : "Det felande kommandot var: \"%s\", name: %s, password: %s",
    "PostgreSQL username and/or password not valid" : "PostgreSQL-användarnamnet och/eller lösenordet är felaktigt",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X stöds inte och %s kommer inte att fungera korrekt på denna plattform. Använd på egen risk!",
    "For the best results, please consider using a GNU/Linux server instead." : "För bästa resultat, överväg att använda en GNU/Linux server istället.",
    "Set an admin username." : "Ange ett användarnamn för administratören.",
    "Set an admin password." : "Ange ett administratörslösenord.",
    "Can't create or write into the data directory %s" : "Kan inte skapa eller skriva till data-katalogen %s",
    "Invalid Federated Cloud ID" : "Ogiltigt \"Federated Cloud\"-ID",
    "%s shared »%s« with you" : "%s delade »%s« med dig",
    "Sharing %s failed, because the backend does not allow shares from type %i" : "Misslyckades dela ut %s då backend inte tillåter delningar från typ %i",
    "Sharing %s failed, because the file does not exist" : "Delning av %s misslyckades på grund av att filen inte existerar",
    "You are not allowed to share %s" : "Du har inte rätt att dela %s",
    "Sharing %s failed, because the user %s does not exist" : "Delning %s misslyckades därför att användaren %s inte existerar",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Delning %s misslyckades därför att användaren %s inte är medlem i någon utav de grupper som %s är medlem i",
    "Sharing %s failed, because this item is already shared with %s" : "Delning %s misslyckades därför att objektet redan är delat med %s",
    "Sharing %s failed, because the group %s does not exist" : "Delning %s misslyckades därför att gruppen %s inte existerar",
    "Sharing %s failed, because %s is not a member of the group %s" : "Delning %s misslyckades därför att %s inte ingår i gruppen %s",
    "You need to provide a password to create a public link, only protected links are allowed" : "Du måste ange ett lösenord för att skapa en offentlig länk, endast skyddade länkar är tillåtna",
    "Sharing %s failed, because sharing with links is not allowed" : "Delning %s misslyckades därför att delning utav länkar inte är tillåtet",
    "Not allowed to create a federated share with the same user" : "Ej tillåtet att skapa en förbundsdelning med samma användare",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Misslyckades dela ut %s, kan inte hitta %s, kanske är servern inte åtkomlig för närvarande.",
    "Share type %s is not valid for %s" : "Delningstyp %s är inte giltig för %s",
    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Misslyckades att sätta rättigheter för %s därför att rättigheterna överskrider de som är tillåtna för %s",
    "Setting permissions for %s failed, because the item was not found" : "Att sätta rättigheterna för %s misslyckades därför att objektet inte hittades",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Kan inte sätta utgångsdatum. Utdelningar kan inte utgå senare än %s efter de har delats ut",
    "Cannot set expiration date. Expiration date is in the past" : "Kan inte sätta utgångsdatum. Utgångsdatumet är i det förflutna.",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Delningsgränssnittet %s måste implementera gränssnittet OCP\\Share_Backend",
    "Sharing backend %s not found" : "Delningsgränssnittet %s hittades inte",
    "Sharing backend for %s not found" : "Delningsgränssnittet för %s hittades inte",
    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Delning %s misslyckades därför att rättigheterna överskrider de rättigheter som är tillåtna för %s",
    "Sharing %s failed, because resharing is not allowed" : "Delning %s misslyckades därför att vidaredelning inte är tillåten",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Delning %s misslyckades därför att delningsgränsnittet för %s inte kunde hitta sin källa",
    "Sharing %s failed, because the file could not be found in the file cache" : "Delning %s misslyckades därför att filen inte kunde hittas i filcachen",
    "Could not find category \"%s\"" : "Kunde inte hitta kategorin \"%s\"",
    "Apps" : "Program",
    "A valid username must be provided" : "Ett giltigt användarnamn måste anges",
    "A valid password must be provided" : "Ett giltigt lösenord måste anges",
    "The username is already being used" : "Användarnamnet används redan",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Inga databasdrivrutiner (sqlite, mysql, eller postgresql) installerade.",
    "Cannot write into \"config\" directory" : "Kan inte skriva till \"config\" katalogen",
    "Cannot write into \"apps\" directory" : "Kan inte skriva till \"apps\" katalogen!",
    "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Detta kan vanligtvis åtgärdas genom att %s ger webbservern skrivrättigheter till applikationskatalogen %s eller stänga av app-butik i konfigurationsfilen.",
    "Cannot create \"data\" directory (%s)" : "Kan inte skapa \"data\" katalog (%s)",
    "This can usually be fixed by <a href=\"%s\" target=\"_blank\">giving the webserver write access to the root directory</a>." : "Detta kan vanligtvis åtgärdas genom att ge <a href=\"%s\" target=\"_blank\">webservern skrivrättigheter till rootkatalogen</a>.",
    "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Rättigheterna kan vanligtvis åtgärdas genom att %s ger webbservern skrivrättigheter till rootkatalogen %s.",
    "Setting locale to %s failed" : "Sätta locale till %s misslyckades",
    "Please install one of these locales on your system and restart your webserver." : "Vänligen installera en av dessa locale på din server och starta om dinn webbserver,",
    "Please ask your server administrator to install the module." : "Vänligen be din administratör att installera modulen.",
    "PHP module %s not installed." : "PHP modulen %s är inte installerad.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Detta orsakas troligtvis av en cache/accelerator som t ex Zend OPchache eller eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP-moduler har installerats, men de listas fortfarande som saknade?",
    "Please ask your server administrator to restart the web server." : "Vänligen be din serveradministratör att starta om webservern.",
    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 krävs",
    "Please upgrade your database version" : "Vänligen uppgradera din databas-version",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Vänligen ändra rättigheterna till 0770 så att katalogen inte kan listas utav andra användare.",
    "Data directory (%s) is readable by other users" : "Datakatalogen (%s) kan läsas av andra användare",
    "Data directory (%s) is invalid" : "Datakatlogen (%s) är ogiltig",
    "Please check that the data directory contains a file \".ocdata\" in its root." : "Vänligen kontrollera att datakatalogen innehåller filen \".ocdata\" i rooten.",
    "Could not obtain lock type %d on \"%s\"." : "Kan inte hämta låstyp %d på \"%s\".",
    "Storage not available" : "Lagring inte tillgänglig"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.0.7.tgz: owncloud/lib/l10n/sv.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Kan inte skriva till \"config\" katalogen!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Detta kan vanligtvis åtgärdas genom att ge skrivrättigheter till config katalgogen",
    "See %s" : "Se %s",
    "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "Detta kan vanligtvis åtgärdas genom att %s ger webbservern skrivrättigheter till konfigurations-katalogen %s.",
    "Sample configuration detected" : "Exempel-konfiguration detekterad",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Det har detekterats att exempel-konfigurationen har kopierats. Detta kan förstöra din installation och stöds ej. Vänligen läs dokumentationen innan ändringar på config.php utförs",
    "PHP %s or higher is required." : "PHP %s eller högre krävs.",
    "PHP with a version lower than %s is required." : "PHP med version lägre än %s krävs.",
    "%sbit or higher PHP required." : "%sbit eller nyare PHP krävs.",
    "Following databases are supported: %s" : "Följande databastyper stödjs: %s",
    "The command line tool %s could not be found" : "Kommandoradsverktyget %s hittades inte.",
    "The library %s is not available." : "Biblioteket %s är inte tillgängligt.",
    "Library %s with a version higher than %s is required - available version %s." : "Bibliotek %s med version högre än %s krävs - tillgänglig version %s.",
    "Library %s with a version lower than %s is required - available version %s." : "Bibliotek %s med version lägre än %s krävs - tillgänglig version %s.",
    "Following platforms are supported: %s" : "Följande plattformar stödjs: %s",
    "ownCloud %s or higher is required." : "ownCloud %s eller högre krävs.",
    "ownCloud %s or lower is required." : "ownCloud %s eller lägre krävs.",
    "Unknown filetype" : "Okänd filtyp",
    "Invalid image" : "Ogiltig bild",
    "today" : "i dag",
    "yesterday" : "i går",
    "_%n day ago_::_%n days ago_" : ["%n dag sedan","%n dagar sedan"],
    "last month" : "förra månaden",
    "_%n month ago_::_%n months ago_" : ["%n månad sedan","%n månader sedan"],
    "last year" : "förra året",
    "_%n year ago_::_%n years ago_" : ["%n år sedan","%n år sedan"],
    "_%n hour ago_::_%n hours ago_" : ["%n timme sedan","%n timmar sedan"],
    "_%n minute ago_::_%n minutes ago_" : ["%n minut sedan","%n minuter sedan"],
    "seconds ago" : "sekunder sedan",
    "Builtin" : "Inbyggt",
    "None" : "Ingen",
    "Username and password" : "Användarnamn och lösenord",
    "Username" : "Användarnamn",
    "Password" : "Lösenord",
    "Log-in credentials, save in session" : "Inloggninguppgifter, spara i sessionen",
    "Empty filename is not allowed" : "Tomt filnamn är inte tillåtet",
    "Dot files are not allowed" : "Punkt-filer är inte tillåtna",
    "4-byte characters are not supported in file names" : "4-bytestecken stöds inte i filnamn",
    "File name is a reserved word" : "Filnamnet är ett reserverat ord",
    "File name contains at least one invalid character" : "Filnamnet innehåller minst ett ogiltigt tecken",
    "File name is too long" : "Filnamnet är för långt",
    "App directory already exists" : "Appens mapp finns redan",
    "Can't create app folder. Please fix permissions. %s" : "Kan inte skapa appens mapp. Var god åtgärda rättigheterna. %s",
    "Archive does not contain a directory named %s" : "Arkivet innehåller inte en mapp som heter %s",
    "No source specified when installing app" : "Ingen källa angiven vid installation av app ",
    "No href specified when installing app from http" : "Ingen href angiven vid installation av app från http",
    "No path specified when installing app from local file" : "Ingen sökväg angiven vid installation av app från lokal fil",
    "Archives of type %s are not supported" : "Arkiv av typen %s stöds ej",
    "Failed to open archive when installing app" : "Kunde inte öppna arkivet när appen skulle installeras",
    "App does not provide an info.xml file" : "Appen har ingen info.xml fil",
    "App cannot be installed because appinfo file cannot be read." : "Appen kunde inte installeras för att filen appinfo inte kunde läsas.",
    "Signature could not get checked. Please contact the app developer and check your admin screen." : "Signaturen kunde inte kontrolleras. Vänligen kontakta apputvecklaren och kontrollera din adminskärm.",
    "App can't be installed because of not allowed code in the App" : "Appen kan inte installeras eftersom att den innehåller otillåten kod",
    "App can't be installed because it is not compatible with this version of ownCloud" : "Appen kan inte installeras eftersom att den inte är kompatibel med denna version av ownCloud",
    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "Appen kan inte installeras eftersom att den innehåller etiketten <shipped>true</shipped> vilket inte är tillåtet för icke inkluderade appar",
    "App can't be installed because the version in info.xml is not the same as the version reported from the app store" : "Appen kunde inte installeras eftersom versionen i info.xml inte är samma som versionen som rapporteras från appstore",
    "Apps" : "Program",
    "General" : "Allmänt",
    "Storage" : "Lagring",
    "Security" : "Säkerhet",
    "Encryption" : "Kryptering",
    "Sharing" : "Dela",
    "Search" : "Sök",
    "Updates" : "Uppdateringar",
    "%s enter the database username." : "%s ange databasanvändare.",
    "%s enter the database name." : "%s ange databasnamn",
    "%s you may not use dots in the database name" : "%s du får inte använda punkter i databasnamnet",
    "Oracle connection could not be established" : "Oracle-anslutning kunde inte etableras",
    "Oracle username and/or password not valid" : "Oracle-användarnamnet och/eller lösenordet är felaktigt",
    "DB Error: \"%s\"" : "DB fel: \"%s\"",
    "Offending command was: \"%s\"" : "Det felaktiga kommandot var: \"%s\"",
    "You need to enter either an existing account or the administrator." : "Du måste antingen ange ett befintligt konto eller administratör.",
    "Offending command was: \"%s\", name: %s, password: %s" : "Det felande kommandot var: \"%s\", name: %s, password: %s",
    "PostgreSQL username and/or password not valid" : "PostgreSQL-användarnamnet och/eller lösenordet är felaktigt",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X stöds inte och %s kommer inte att fungera korrekt på denna plattform. Använd på egen risk!",
    "For the best results, please consider using a GNU/Linux server instead." : "För bästa resultat, överväg att använda en GNU/Linux server istället.",
    "Set an admin username." : "Ange ett användarnamn för administratören.",
    "Set an admin password." : "Ange ett administratörslösenord.",
    "Can't create or write into the data directory %s" : "Kan inte skapa eller skriva till data-katalogen %s",
    "Invalid Federated Cloud ID" : "Ogiltigt \"Federated Cloud\"-ID",
    "%s shared »%s« with you" : "%s delade »%s« med dig",
    "Sharing %s failed, because the backend does not allow shares from type %i" : "Misslyckades dela ut %s då backend inte tillåter delningar från typ %i",
    "Sharing %s failed, because the file does not exist" : "Delning av %s misslyckades på grund av att filen inte existerar",
    "You are not allowed to share %s" : "Du har inte rätt att dela %s",
    "Sharing %s failed, because the user %s does not exist" : "Delning %s misslyckades därför att användaren %s inte existerar",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Delning %s misslyckades därför att användaren %s inte är medlem i någon utav de grupper som %s är medlem i",
    "Sharing %s failed, because this item is already shared with %s" : "Delning %s misslyckades därför att objektet redan är delat med %s",
    "Sharing %s failed, because the group %s does not exist" : "Delning %s misslyckades därför att gruppen %s inte existerar",
    "Sharing %s failed, because %s is not a member of the group %s" : "Delning %s misslyckades därför att %s inte ingår i gruppen %s",
    "You need to provide a password to create a public link, only protected links are allowed" : "Du måste ange ett lösenord för att skapa en offentlig länk, endast skyddade länkar är tillåtna",
    "Sharing %s failed, because sharing with links is not allowed" : "Delning %s misslyckades därför att delning utav länkar inte är tillåtet",
    "Not allowed to create a federated share with the same user" : "Ej tillåtet att skapa en förbundsdelning med samma användare",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Misslyckades dela ut %s, kan inte hitta %s, kanske är servern inte åtkomlig för närvarande.",
    "Share type %s is not valid for %s" : "Delningstyp %s är inte giltig för %s",
    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Misslyckades att sätta rättigheter för %s därför att rättigheterna överskrider de som är tillåtna för %s",
    "Setting permissions for %s failed, because the item was not found" : "Att sätta rättigheterna för %s misslyckades därför att objektet inte hittades",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Kan inte sätta utgångsdatum. Utdelningar kan inte utgå senare än %s efter de har delats ut",
    "Cannot set expiration date. Expiration date is in the past" : "Kan inte sätta utgångsdatum. Utgångsdatumet är i det förflutna.",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Delningsgränssnittet %s måste implementera gränssnittet OCP\\Share_Backend",
    "Sharing backend %s not found" : "Delningsgränssnittet %s hittades inte",
    "Sharing backend for %s not found" : "Delningsgränssnittet för %s hittades inte",
    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Delning %s misslyckades därför att rättigheterna överskrider de rättigheter som är tillåtna för %s",
    "Sharing %s failed, because resharing is not allowed" : "Delning %s misslyckades därför att vidaredelning inte är tillåten",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Delning %s misslyckades därför att delningsgränsnittet för %s inte kunde hitta sin källa",
    "Sharing %s failed, because the file could not be found in the file cache" : "Delning %s misslyckades därför att filen inte kunde hittas i filcachen",
    "Could not find category \"%s\"" : "Kunde inte hitta kategorin \"%s\"",
    "A valid username must be provided" : "Ett giltigt användarnamn måste anges",
    "A valid password must be provided" : "Ett giltigt lösenord måste anges",
    "The username is already being used" : "Användarnamnet används redan",
    "Help" : "Hjälp",
    "Settings" : "Inställningar",
    "Users" : "Användare",
    "web services under your control" : "webbtjänster under din kontroll",
    "Application is not enabled" : "Applikationen är inte aktiverad",
    "Authentication error" : "Fel vid autentisering",
    "Token expired. Please reload page." : "Ogiltig token. Ladda om sidan.",
    "Unknown user" : "Okänd användare",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Inga databasdrivrutiner (sqlite, mysql, eller postgresql) installerade.",
    "Cannot write into \"config\" directory" : "Kan inte skriva till \"config\" katalogen",
    "Cannot write into \"apps\" directory" : "Kan inte skriva till \"apps\" katalogen!",
    "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Detta kan vanligtvis åtgärdas genom att %s ger webbservern skrivrättigheter till applikationskatalogen %s eller stänga av app-butik i konfigurationsfilen.",
    "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Rättigheterna kan vanligtvis åtgärdas genom att %s ger webbservern skrivrättigheter till rootkatalogen %s.",
    "Setting locale to %s failed" : "Sätta locale till %s misslyckades",
    "Please install one of these locales on your system and restart your webserver." : "Vänligen installera en av dessa locale på din server och starta om dinn webbserver,",
    "Please ask your server administrator to install the module." : "Vänligen be din administratör att installera modulen.",
    "PHP module %s not installed." : "PHP modulen %s är inte installerad.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Detta orsakas troligtvis av en cache/accelerator som t ex Zend OPchache eller eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP-moduler har installerats, men de listas fortfarande som saknade?",
    "Please ask your server administrator to restart the web server." : "Vänligen be din serveradministratör att starta om webservern.",
    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 krävs",
    "Please upgrade your database version" : "Vänligen uppgradera din databas-version",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Vänligen ändra rättigheterna till 0770 så att katalogen inte kan listas utav andra användare.",
    "Please check that the data directory contains a file \".ocdata\" in its root." : "Vänligen kontrollera att datakatalogen innehåller filen \".ocdata\" i rooten.",
    "Could not obtain lock type %d on \"%s\"." : "Kan inte hämta låstyp %d på \"%s\".",
    "Storage is temporarily not available" : "Lagring är temporärt inte tillgänglig"
},
"nplurals=2; plural=(n != 1);");
